$ErrorActionPreference = 'silentlycontinue'
$user_tool = Get-ChildItem -Path $Env:APPDATA\Alteryx\Tools 
$admin_tool = Get-ChildItem -Path $Env:ALLUSERSPROFILE\Alteryx\Tools
$admin_install_reg = Get-ItemProperty -Path Registry::HKEY_LOCAL_MACHINE\SOFTWARE\WOW6432Node\SRC\Alteryx -Name InstallDir64 
$nonadmin_install_reg = Get-ItemProperty -Path Registry::HKEY_CURRENT_USER\Software\SRC\Alteryx -Name InstallDir64
$admin_path = $admin_install_reg.InstallDir64 + "\HtmlPlugins"
$nonadmin_path = $nonadmin_install_reg.InstallDir64 + "\HtmlPlugins"
$admin_install_tool = Get-ChildItem -Path $admin_path
$nonadmin_install_tool = Get-ChildItem -Path $nonadmin_path
$upgrade_version = "3.8.5"
$combine_paths = $user_tool + $admin_tool + $admin_install_tool + $nonadmin_install_tool

$file = 1
foreach ($path in $combine_paths)
{
    $xml_path = Get-ChildItem -Path $path.FullName -Filter *.xml 
    [xml]$read_xml = Get-Content $xml_path.FullName
    $python_version = $path.FullName + "\Python.exe" 
    $cmd_output = cmd /c $python_version "-V" '2>&1' | Out-String
    $output_split = $cmd_output.Split(" ") 
    if ($output_split[1] -eq "is")
    {
        $python_version = $path.FullName + "\Scripts\Python.exe"
        $cmd_output = cmd /c $python_version "-V" '2>&1' | Out-String
        $output_split = $cmd_output.Split(" ") 
    }
    $search_files = Get-ChildItem -Path $path.FullName -Recurse -Filter *.pyd | Where-Object {$_.FullName -match 'cp3[0-7]'}
    $percentage_complete = [math]::Round(($file/$combine_paths.Count)*100)
    Write-Progress -Activity "Searching Alteryx Tools..." -Status "Checking Files: $percentage_complete% Complete";
    if ($search_files) {
        
       $out =  @([pscustomobject]@{
            "Tool Name" = $read_xml.AlteryxJavaScriptPlugin.Properties.MetaInfo.Name 
            "Tool Version" = $read_xml.AlteryxJavaScriptPlugin.Properties.MetaInfo.ToolVersion
            "Python Version" = $output_split[1]
            "Path" = $path.FullName 
            } 
       ) 
       $out_list +=$out
    }
    $file = $file + 1
}
if($out_list) {
    Write-Output "The following tools are incompatible with Python version [$upgrade_version]."
    $out_list | Format-Table -Wrap -AutoSize
} 
else 
{
    Write-Output "Did not find any tools that are incompatible with Python version [$upgrade_version]."
}


